@@ -10,11 +10,14 @@ is not directly referenced by end users.
 from typing import Literal
 __all__ = ['api_prefix', 'argus_prefix', 'DATETIME_COL_FMT', 'DEPLOY_TYPE', 'EXPECTED_DELIVERY', 'WORK_ORDER_PRIORITY',
            'WORK_ORDER_STATUS', 'WORK_ORDER_CATEGORY', 'ERROR_TYPE', 'MAPPING_ENTITIES', 'QUEUE_NAME', 'QUERY_LANGUAGE',
-           'ACCOUNT']
+           'ACCOUNT', 'PROCESS_STATUS']
 # api_prefix = "http://localhost:7071/api/SwitchApi/"
 api_prefix = "https://pivotstreams.azurewebsites.net/api/SwitchApi/"
+
+# argus_prefix = "http://localhost:7071/api/"
 argus_prefix = "https://arguslogicv4b.azurewebsites.net/api/"
 
+
 DATETIME_COL_FMT = Literal['DateTime', 'Date', 'Time']
 
 # ['DateTime in 1 column',
