@@ -15,7 +15,10 @@ import secrets
 import pandas
 import pandera
 from .._utils._constants import WORK_ORDER_STATUS, WORK_ORDER_CATEGORY, WORK_ORDER_PRIORITY
+
 __all__ = ['generate_password', 'convert_to_sqm', 'ValidatedSetterProperty', 'ApiInputs']
+
+
 # import requests
 # import logging
 # import sys
@@ -52,6 +55,7 @@ def _with_func_attrs(**attrs):
         for k, v in attrs.items():
             setattr(f, k, v)
         return f
+
     return with_attrs
 
 
@@ -81,6 +85,20 @@ ApiInputs = namedtuple('ApiInputs',
                         'data_feed_id', 'data_feed_file_status_id'])
 
 
+DataFeedFileProcessOutput = namedtuple('DataFeedFileProcessOutput',
+                                       [
+                                           'data_feed_id', 'data_feed_file_status_id',
+                                           'client_tracking_id',
+                                           'source_type', 'file_name', 'file_received',
+                                           'file_process_status',
+                                           'file_process_status_change', 'process_started',
+                                           'process_completed',
+                                           'minutes_since_received', 'minutes_since_processed',
+                                           'file_size',
+                                           'log_file_path', 'output', 'error'
+                                       ])
+
+
 def generate_password():
     """Generate a ten-character alphanumeric password with at least one lowercase character, at least one uppercase
     character, and at least three digits.
@@ -136,7 +154,6 @@ _site_schema = pandera.DataFrameSchema(
     }
 )
 
-
 _work_order_schema = pandera.DataFrameSchema(
     columns={
         'WorkOrderId': pandera.Column(pandera.String, required=True),
@@ -181,7 +198,6 @@ _work_order_schema = pandera.DataFrameSchema(
     name=None
 )
 
-
 # def adx_support(api_inputs: ApiInputs, build_sites=False, build_sensors=False):
 #     adx_support_prefix = ''
 #     if api_inputs.datacentre == 'AU':
