@@ -123,10 +123,10 @@ def upsert_device_sensors(df: pandas.DataFrame, api_inputs: ApiInputs, tag_colum
 
     url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Integration/DeviceSensors/Upsert"
 
-    data_frame_grpd = data_frame.groupby('DeviceCode')
+    data_frame_grpd = data_frame.groupby(['InstallationCode', 'DeviceCode'])
     chunk_list = []
     for name, group in data_frame_grpd:
-        logger.info('Upserting data for DeviceCode = %s', str(name))
+        logger.info('Upserting data for InstallationCode = %s and DeviceCode = %s', str(name[0]), str(name[1]))
         # logger.info('Sensor count to upsert: %s', str(group.shape[0]))
 
         response = requests.post(url, data=group.to_json(orient='records'), headers=headers)
@@ -135,30 +135,34 @@ def upsert_device_sensors(df: pandas.DataFrame, api_inputs: ApiInputs, tag_colum
         if response.status_code != 200:
             logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
                          response.reason)
-            chunk_list += [{'Chunk': str(name), 'DeviceCountToUpsert': 1, 'SensorCountToUpsert': str(group.shape[0]),
+            chunk_list += [{'Chunk': name, 'DeviceCountToUpsert': 1, 'SensorCountToUpsert': str(group.shape[0]),
                             'response_status': response_status, 'response_df': pandas.DataFrame(),
                             'invalid_rows': pandas.DataFrame()}]
         elif len(response.text) == 0:
             logger.error('No data returned for this API call. %s', response.request.__dict__)
-            chunk_list += [{'Chunk': str(name), 'DeviceCountToUpsert': 1, 'SensorCountToUpsert': str(group.shape[0]),
+            chunk_list += [{'Chunk': name, 'DeviceCountToUpsert': 1, 'SensorCountToUpsert': str(group.shape[0]),
                             'response_status': response_status, 'response_df': pandas.DataFrame(),
                             'invalid_rows': pandas.DataFrame()}]
-
-        response_data_frame = pandas.read_json(response.text)
-        logger.info('Dataframe response row count = %s', str(response_data_frame.shape[0]))
-        if response_data_frame.shape[1] > 0:
-            invalid_rows = response_data_frame[response_data_frame['status'] != 'Ok']
-            if invalid_rows.shape[0] > 0:
-                logger.error("The following rows contain invalid data: %s", invalid_rows)
-                chunk_list += [
-                    {'Chunk': str(name), 'DeviceCountToUpsert': 1, 'SensorCountToUpsert': str(group.shape[0]),
-                     'response_status': response_status, 'response_df': response_data_frame,
-                     'invalid_rows': invalid_rows}]
-            else:
-                chunk_list += [{'Chunk': str(name), 'DeviceCountToUpsert': 1,
-                                'SensorCountToUpsert': str(group.shape[0]),
-                                'response_status': response_status, 'response_df': response_data_frame,
-                                'invalid_rows': pandas.DataFrame()}]
+        elif response.status_code == 200 and len(response.text) > 0:
+            response_data_frame = pandas.read_json(response.text)
+            logger.info('Dataframe response row count = %s', str(response_data_frame.shape[0]))
+            if response_data_frame.shape[1] > 0:
+                response_data_frame = response_data_frame.assign(InstallationCode=str(name[0]),
+                                                                 SensorCount=group.shape[0])
+                invalid_rows = response_data_frame[response_data_frame['status'] != 'Ok']
+                if invalid_rows.shape[0] > 0:
+                    logger.error("The following rows contain invalid data: %s", invalid_rows)
+                    chunk_list += [
+                        {'Chunk': name, 'DeviceCountToUpsert': 1,
+                         'SensorCountToUpsert': str(group.shape[0]),
+                         'response_status': response_status,
+                         'response_df': response_data_frame[response_data_frame['status'] == 'Ok'],
+                         'invalid_rows': invalid_rows}]
+                else:
+                    chunk_list += [{'Chunk': name, 'DeviceCountToUpsert': 1,
+                                    'SensorCountToUpsert': str(group.shape[0]),
+                                    'response_status': response_status, 'response_df': response_data_frame,
+                                    'invalid_rows': invalid_rows}]
 
     upsert_response_df = pandas.DataFrame()
     upsert_invalid_rows_df = pandas.DataFrame()
@@ -377,13 +381,6 @@ def upsert_workorders(df: pandas.DataFrame, api_inputs: ApiInputs, save_addition
     optional_columns = ['SubType', 'Vendor', 'VendorId', 'EquipmentClass', 'RawEquipmentClass', 'EquipmentLabel',
                         'RawEquipmentId', 'TenantId', 'TenantName', 'NotToExceedCost', 'TotalCost', 'BillableCost',
                         'NonBillableCost', 'Location', 'RawLocation', 'ScheduledStartDate', 'ScheduledCompletionDate']
-    # optional_columns_df = pandas.DataFrame({'ColumnName': ['SubType', 'Vendor', 'VendorId', 'EquipmentClass',
-    #                                                        'RawEquipmentClass', 'EquipmentLabel', 'RawEquipmentId',
-    #                                                        'TenantId', 'TenantName', 'NotToExceedCost', 'TotalCost',
-    #                                                        'BillableCost',  'NonBillableCost', 'Location',
-    #                                                        'RawLocation', 'ScheduledStartDate',
-    #                                                        'ScheduledCompletionDate'],
-    #                                         })
 
     req_cols = ', '.join(required_columns)
     proposed_columns = data_frame.columns.tolist()
@@ -435,7 +432,7 @@ def upsert_workorders(df: pandas.DataFrame, api_inputs: ApiInputs, save_addition
                                     'EquipmentClass', 'RawEquipmentClass', 'EquipmentLabel', 'RawEquipmentId',
                                     'TenantId', 'TenantName', 'NotToExceedCost', 'TotalCost', 'BillableCost',
                                     'NonBillableCost', 'Location', 'RawLocation', 'ScheduledStartDate',
-                                    'ScheduledCompletionDate']]
+                                    'ScheduledCompletionDate', 'Meta']]
 
     upload_result = Blob.upload(api_inputs=api_inputs, data_frame=data_frame, name='WorkOrder',
                                 api_project_id=api_inputs.api_project_id, is_timeseries=True)
@@ -466,7 +463,7 @@ def upsert_workorders(df: pandas.DataFrame, api_inputs: ApiInputs, save_addition
 @_with_func_attrs(df_required_columns=['ObjectPropertyId', 'InstallationId', 'Timestamp', 'Value'])
 def upsert_timeseries_ds(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_time: bool = True,
                          save_additional_columns_as_slices: bool = False, data_feed_file_status_id: uuid.UUID = None):
-    """Appends data to Timeseries_Ds table.
+    """Upserts to Timeseries_Ds table.
 
     The following columns are required to be present in the data_frame:
     - InstallationId
@@ -721,7 +718,7 @@ def replace_data(data_frame, api_inputs: ApiInputs, table_name: str):
     Parameters
     ----------
     data_frame : pandas.DataFrame
-
+        Data frame to be used to replace the data in the `table_name` table.
     api_inputs : ApiInputs
         Object returned by initialize() function.
     table_name :
